@@ -8,10 +8,9 @@ from notecoin.okex.websocket.utils import get_local_timestamp
 class BaseHandle:
     def __init__(self, channels, *args, **kwargs):
         self.channels = channels
-
     def solve(self, data) -> bool:
         data = eval(data)
-        print(f"{get_local_timestamp()}\t{len(data)}")
+
         if 'event' in data:
             return False
 
@@ -20,7 +19,7 @@ class BaseHandle:
             return self.handle(data)
 
     def handle(self, data) -> bool:
-        print(f"{data['arg']['channel']}:{len(str(data))}")
+        print(f"{get_local_timestamp()}\t{data['arg']['channel']}\t{len(str(data))}")
         return True
 
 
