@@ -1,7 +1,7 @@
 import logging
 
 from notecoin.okex.websocket.channel import PrivateChannel, PublicChannel
-from notecoin.okex.websocket.connect import PrivateConnect
+from notecoin.okex.websocket.connect import PublicConnect
 from notecoin.okex.websocket.handle import BaseHandle, PublicTickers
 from notetool.secret import read_secret
 
@@ -12,10 +12,10 @@ read_secret(cate1='notecoin', cate2='dataset', cate3='db_path', value=uri)
 logger = logging.getLogger()
 logger.setLevel(logging.DEBUG)
 
-connect = PrivateConnect([
+connect = PublicConnect([
     PublicChannel.public_tickers().to_json(),
-    PrivateChannel.private_positions()
+    #  PrivateChannel.private_positions()
 ])
-connect.add_handle(BaseHandle("positions"))
+# connect.add_handle(BaseHandle("positions"))
 connect.add_handle(PublicTickers())
 connect.run()
